==> scathach-api-1.4.2.tar.gz: scathach-api-1.4.2/scathach/scathach.py <==
import urllib

from . import http, dict, errors

noresponse = "Couldn't contact the API right now..."

def gif():
    try:
        return http.get("/gif/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)


def jav():
    try:
        return http.get("/jav/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)


def twitter():
    try:
        return http.get("/twitter/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def real():
    try:
        return http.get("/rb/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def fgo():
    try:
        return http.get("/r34/?tags=fate/grand_order")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def armpits():
    try:
        return http.get("/r34/?tags=armpits")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def armpit_hair():
    try:
        return http.get("/r34/?tags=armpit_hair")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def armpit_licking():
    try:
        return http.get("/r34/?tags=armpit_licking")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def smell():
    try:
        return http.get("/r34/?tags=smell")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pantyhose():
    try:
        return http.get("/r34/?tags=pantyhose")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def large_breasts():
    try:
        return http.get("/r34/?tags=large_breasts")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def blush():
    try:
        return http.get("/r34/?tags=blush")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def blowjob():
    try:
        return http.get("/r34/?tags=blowjob")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def masturbation():
    try:
        return http.get("/r34/?tags=masturbation")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pervert():
    try:
        return http.get("/r34/?tags=pervert")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pubic_hair():
    try:
        return http.get("/r34/?tags=pubic_hair")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def sweat():
    try:
        return http.get("/r34/?tags=sweat")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def footjob():
    try:
        return http.get("/r34/?tags=footjob")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def foot_licking():
    try:
        return http.get("/r34/?tags=foot_licking")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def housewife():
    try:
        return http.get("/r34/?tags=housewife")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def milf():
    try:
        return http.get("/r34/?tags=milf")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def school_uniform():
    try:
        return http.get("/r34/?tags=school_uniform")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def bikini():
    try:
        return http.get("/r34/?tags=bikini")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def cowgirl_position():
    try:
        return http.get("/r34/?tags=cowgirl_position")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def doggystyle():
    try:
        return http.get("/r34/?tags=doggystyle")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def dark_skin():
    try:
        return http.get("/r34/?tags=dark_skin")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def animated():
    try:
        return http.get("/r34/?tags=animated")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gangbang():
    try:
        return http.get("/r34/?tags=gangbang")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def clothed_sex():
    try:
        return http.get("/r34/?tags=clothed_sex")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def uncensored():
    try:
        return http.get("/r34/?tags=uncensored")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def twintails():
    try:
        return http.get("/r34/?tags=twintails")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pussy_juice():
    try:
        return http.get("/r34/?tags=pussy_juice")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def rape():
    try:
        return http.get("/r34/?tags=rape")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def double_penetration():
    try:
        return http.get("/r34/?tags=double_penetration")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def futanari():
    try:
        return http.get("/r34/?tags=futanari")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def yaoi():
    try:
        return http.get("/r34/?tags=yaoi")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def yuri():
    try:
        return http.get("/r34/?tags=yuri")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ass():
    try:
        return http.get("/r34/?tags=ass")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pregnant():
    try:
        return http.get("/r34/?tags=pregnant")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def netorare():
    try:
        return http.get("/r34/?tags=netorare")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ugly_man():
    try:
        return http.get("/r34/?tags=ugly_man")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pout():
    try:
        return http.get("/r34/?tags=pout")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def cum():
    try:
        return http.get("/r34/?tags=cum")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def thick():
    try:
        return http.get("/r34/?tags=thick")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

==> scathach-api-1.4.3.tar.gz: scathach-api-1.4.3/scathach/scathach.py <==
import urllib

from . import http, dict, errors

noresponse = "Couldn't contact the API right now..."

def gif():
    try:
        return http.get("/gif/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)


def jav():
    try:
        return http.get("/jav/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)


def twitter():
    try:
        return http.get("/twitter/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def real():
    try:
        return http.get("/rb/")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def fgo():
    try:
        return http.get("/r34/?tags=fate/grand_order")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def armpits():
    try:
        return http.get("/r34/?tags=armpits")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def armpit_hair():
    try:
        return http.get("/r34/?tags=armpit_hair")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def armpit_licking():
    try:
        return http.get("/r34/?tags=armpit_licking")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def smell():
    try:
        return http.get("/r34/?tags=smell")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pantyhose():
    try:
        return http.get("/r34/?tags=pantyhose")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def large_breasts():
    try:
        return http.get("/r34/?tags=large_breasts")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def blush():
    try:
        return http.get("/r34/?tags=blush")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def blowjob():
    try:
        return http.get("/r34/?tags=blowjob")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def masturbation():
    try:
        return http.get("/r34/?tags=masturbation")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pervert():
    try:
        return http.get("/r34/?tags=pervert")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pubic_hair():
    try:
        return http.get("/r34/?tags=pubic_hair")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def sweat():
    try:
        return http.get("/r34/?tags=sweat")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def footjob():
    try:
        return http.get("/r34/?tags=footjob")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def foot_licking():
    try:
        return http.get("/r34/?tags=foot_licking")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def housewife():
    try:
        return http.get("/r34/?tags=housewife")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def milf():
    try:
        return http.get("/r34/?tags=milf")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def school_uniform():
    try:
        return http.get("/r34/?tags=school_uniform")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def bikini():
    try:
        return http.get("/r34/?tags=bikini")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def cowgirl_position():
    try:
        return http.get("/r34/?tags=cowgirl_position")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def doggystyle():
    try:
        return http.get("/r34/?tags=doggystyle")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def dark_skin():
    try:
        return http.get("/r34/?tags=dark_skin")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def animated():
    try:
        return http.get("/r34/?tags=animated")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gangbang():
    try:
        return http.get("/r34/?tags=gangbang")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def clothed_sex():
    try:
        return http.get("/r34/?tags=clothed_sex")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def uncensored():
    try:
        return http.get("/r34/?tags=uncensored")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def twintails():
    try:
        return http.get("/r34/?tags=twintails")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pussy_juice():
    try:
        return http.get("/r34/?tags=pussy_juice")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def rape():
    try:
        return http.get("/r34/?tags=rape")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def double_penetration():
    try:
        return http.get("/r34/?tags=double_penetration")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def futanari():
    try:
        return http.get("/r34/?tags=futanari")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def yaoi():
    try:
        return http.get("/r34/?tags=yaoi")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def yuri():
    try:
        return http.get("/r34/?tags=yuri")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ass():
    try:
        return http.get("/r34/?tags=ass")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pregnant():
    try:
        return http.get("/r34/?tags=pregnant")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def netorare():
    try:
        return http.get("/r34/?tags=netorare")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ugly_man():
    try:
        return http.get("/r34/?tags=ugly_man")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def pout():
    try:
        return http.get("/r34/?tags=pout")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def cum():
    try:
        return http.get("/r34/?tags=cum")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def thick():
    try:
        return http.get("/r34/?tags=thick")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def scathach():
    try:
        return http.get("/r34/?tags=scathach_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def raikou():
    try:
        return http.get("/r34/?tags=minamoto_no_raikou_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def jeanne():
    try:
        return http.get("/r34/?tags=jeanne_d'arc_(fate)_(all)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ereshkigal():
    try:
        return http.get("/r34/?tags=ereshkigal_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def artoria():
    try:
        return http.get("/r34/?tags=artoria_pendragon_(all)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def okita():
    try:
        return http.get("/r34/?tags=okita_souji_(fate)_(all)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def kama():
    try:
        return http.get("/r34/?tags=kama_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def davinci():
    try:
        return http.get("/r34/?tags=leonardo_da_vinci_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def anastasia():
    try:
        return http.get("/r34/?tags=anastasia_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def saint_martha():
    try:
        return http.get("/r34/?tags=saint_martha")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gudako():
    try:
        return http.get("/r34/?tags=fujimaru_ritsuka_(female)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def mashu():
    try:
        return http.get("/r34/?tags=mash_kyrielight")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def abigail():
    try:
        return http.get("/r34/?tags=abigail_williams_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ushiwakamaru():
    try:
        return http.get("/r34/?tags=ushiwakamaru_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def consort_yu():
    try:
        return http.get("/r34/?tags=consort_yu_(fate)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def mordred():
    try:
        return http.get("/r34/?tags=himiko_(fate)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def himiko():
    try:
        return http.get("/r34/?tags=thick")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def kiara():
    try:
        return http.get("/r34/?tags=sesshouin_kiara")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def xuanzang():
    try:
        return http.get("/r34/?tags=xuanzang_(fate/grand_order)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def bb():
    try:
        return http.get("/r34/?tags=bb_(fate)_(all)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def nero():
    try:
        return http.get("/r34/?tags=nero_claudius_(fate)_(all)")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)
